@@ -4,7 +4,10 @@ SelectProductList = function (params) {
     var $container = params.$container;
 
     function handleListItemDoubleClick() {
-        $(window).trigger('product-selected', [$(this).data('item-id')]);
+        $(window).trigger('product-selected', [
+            $(this).data('item-id'),
+            {focus: true}
+        ]);
     }
 
     function handleItemUpdated(event, item) {
